Class: CopyTunerClient::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/copy_tuner_client/configuration.rb

Overview

Used to set up and modify settings for the client.

Constant Summary collapse

OPTIONS =

These options will be present in the Hash returned by #to_hash.

%i[api_key development_environments environment_name host
http_open_timeout http_read_timeout client_name client_url
client_version port protocol proxy_host proxy_pass
proxy_port proxy_user secure polling_delay sync_interval
sync_interval_staging sync_ignore_path_regex logger
framework middleware disable_middleware disable_test_translation
ca_file exclude_key_regexp local_first_key_regexp s3_host locales ignored_keys ignored_key_handler
download_cache_dir].freeze
BUILTIN_LOCAL_FIRST_KEY_REGEXP =

NOTE: Rails 標準ロケールで非文字列値(precision: Integer, significant: Boolean, strip_insignificant_zeros: Boolean)を含むのは number.*.format 配下のみ。store_item が文字列しか保持できず lookup_in_tree_cache が tree cache をローカル YAML より優先するため、CopyTuner 経由だとprecision 等が欠落し number_to_currency 等が壊れる。これらの Rails 標準 format キーだけを常にローカル優先にする(number 全体ではなく、アプリ独自の number.* キーは対象外)。末尾 (.|z) でnumber.currency.format(ハッシュ lookup)と number.currency.format.precision(葉キー)の両方に対応する。

/\Anumber\.(format|currency\.format|percentage\.format|human\.format)(\.|\z)/

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Instantiated from CopyTunerClient.configure. Sets defaults.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/copy_tuner_client/configuration.rb', line 168

def initialize
  self.client_name = 'CopyTuner Client'
  self.client_url = 'https://rubygems.org/gems/copy_tuner_client'
  self.client_version = VERSION
  self.development_environments = %w[development staging]
  self.host = 'copy-tuner.com'
  self.http_open_timeout = 5
  self.http_read_timeout = 5
  self.logger = Logger.new($stdout)
  self.polling_delay = 300
  self.sync_interval = 60
  self.sync_interval_staging = 0
  self.secure = true
  self.test_environments = %w[test cucumber]
  self.upload_disabled_environments = %w[production staging]
  self.s3_host = 'copy-tuner.sg-apps.com' # NOTE: cloudfront host
  self.disable_copyray_comment_injection = false
  self.html_escape = true
  self.ignored_keys = []
  self.ignored_key_handler = ->(e) { raise e }
  self.local_first_key_regexp = nil
  self.project_id = nil
  self.download_cache_dir = Pathname.new(Dir.pwd).join('tmp', 'cache', 'copy_tuner_client')

  @applied = false
end

Instance Attribute Details

#api_keyString

Returns The API key for your project, found on the project edit form.

Returns:

  • (String)

    The API key for your project, found on the project edit form.



40
41
42
# File 'lib/copy_tuner_client/configuration.rb', line 40

def api_key
  @api_key
end

#ca_fileString

Returns the path to a root certificate file used to verify ssl sessions. Default’s to the root certificate file for copy-tuner.com.

Returns:

  • (String)

    the path to a root certificate file used to verify ssl sessions. Default’s to the root certificate file for copy-tuner.com.



121
122
123
# File 'lib/copy_tuner_client/configuration.rb', line 121

def ca_file
  @ca_file
end

#cacheCache

Returns instance used internally to synchronize changes.

Returns:

  • (Cache)

    instance used internally to synchronize changes.



124
125
126
# File 'lib/copy_tuner_client/configuration.rb', line 124

def cache
  @cache
end

#clientClient

Returns instance used to communicate with a CopyTuner Server.

Returns:

  • (Client)

    instance used to communicate with a CopyTuner Server.



127
128
129
# File 'lib/copy_tuner_client/configuration.rb', line 127

def client
  @client
end

#client_nameString

Returns The name of the client library being used to send notifications (defaults to CopyTuner Client).

Returns:

  • (String)

    The name of the client library being used to send notifications (defaults to CopyTuner Client)



82
83
84
# File 'lib/copy_tuner_client/configuration.rb', line 82

def client_name
  @client_name
end

#client_urlString

Returns The url of the client library being used.

Returns:

  • (String)

    The url of the client library being used



91
92
93
# File 'lib/copy_tuner_client/configuration.rb', line 91

def client_url
  @client_url
end

#client_versionString

Returns The version of the client library being used to send notifications (such as 1.0.2).

Returns:

  • (String)

    The version of the client library being used to send notifications (such as 1.0.2)



88
89
90
# File 'lib/copy_tuner_client/configuration.rb', line 88

def client_version
  @client_version
end

#development_environmentsArray<String>

Returns A list of environments in which content should be editable.

Returns:

  • (Array<String>)

    A list of environments in which content should be editable



70
71
72
# File 'lib/copy_tuner_client/configuration.rb', line 70

def development_environments
  @development_environments
end

#disable_copyray_comment_injectionBoolean

Returns To disable Copyray comment injection, set true.

Returns:

  • (Boolean)

    To disable Copyray comment injection, set true



145
146
147
# File 'lib/copy_tuner_client/configuration.rb', line 145

def disable_copyray_comment_injection
  @disable_copyray_comment_injection
end

#disable_middlewareBoolean

Returns disable middleware setting.

Returns:

  • (Boolean)

    disable middleware setting



112
113
114
# File 'lib/copy_tuner_client/configuration.rb', line 112

def disable_middleware
  @disable_middleware
end

#disable_test_translationBoolean

Returns disable download translation for test enviroment.

Returns:

  • (Boolean)

    disable download translation for test enviroment



118
119
120
# File 'lib/copy_tuner_client/configuration.rb', line 118

def disable_test_translation
  @disable_test_translation
end

#download_cache_dirPathname

Returns The directory to cache downloaded files.

Returns:

  • (Pathname)

    The directory to cache downloaded files



163
164
165
# File 'lib/copy_tuner_client/configuration.rb', line 163

def download_cache_dir
  @download_cache_dir
end

#environment_nameString

Returns The name of the environment the application is running in.

Returns:

  • (String)

    The name of the environment the application is running in



79
80
81
# File 'lib/copy_tuner_client/configuration.rb', line 79

def environment_name
  @environment_name
end

#exclude_key_regexpRegexp

Deprecated.

Returns Regular expression to exclude keys.

Returns:

  • (Regexp)

    Regular expression to exclude keys.



133
134
135
# File 'lib/copy_tuner_client/configuration.rb', line 133

def exclude_key_regexp
  @exclude_key_regexp
end

#frameworkString, NilClass

Returns The framework notifications are being sent from, if any (such as Rails 2.3.9).

Returns:

  • (String, NilClass)

    The framework notifications are being sent from, if any (such as Rails 2.3.9)



85
86
87
# File 'lib/copy_tuner_client/configuration.rb', line 85

def framework
  @framework
end

#hostString

Returns The host to connect to (defaults to copy-tuner.com).

Returns:

  • (String)

    The host to connect to (defaults to copy-tuner.com).



43
44
45
# File 'lib/copy_tuner_client/configuration.rb', line 43

def host
  @host
end

#html_escapeBoolean

Returns Html escape.

Returns:

  • (Boolean)

    Html escape



151
152
153
# File 'lib/copy_tuner_client/configuration.rb', line 151

def html_escape
  @html_escape
end

#http_open_timeoutFixnum

Returns The HTTP open timeout in seconds (defaults to 2).

Returns:

  • (Fixnum)

    The HTTP open timeout in seconds (defaults to 2).



52
53
54
# File 'lib/copy_tuner_client/configuration.rb', line 52

def http_open_timeout
  @http_open_timeout
end

#http_read_timeoutFixnum

Returns The HTTP read timeout in seconds (defaults to 5).

Returns:

  • (Fixnum)

    The HTTP read timeout in seconds (defaults to 5).



55
56
57
# File 'lib/copy_tuner_client/configuration.rb', line 55

def http_read_timeout
  @http_read_timeout
end

#ignored_key_handlerProc

Returns:

  • (Proc)


157
158
159
# File 'lib/copy_tuner_client/configuration.rb', line 157

def ignored_key_handler
  @ignored_key_handler
end

#ignored_keysArray<String>

Returns A list of ignored keys.

Returns:

  • (Array<String>)

    A list of ignored keys



154
155
156
# File 'lib/copy_tuner_client/configuration.rb', line 154

def ignored_keys
  @ignored_keys
end

#local_first_key_regexpRegexp

Returns Keys (without locale) matching this regexp bypass the copy_tuner cache and are looked up from local config/locales (I18n::Backend::Simple) first. Used for gradual migration from copy_tuner to local YAML.

Returns:

  • (Regexp)

    Keys (without locale) matching this regexp bypass the copy_tuner cache and are looked up from local config/locales (I18n::Backend::Simple) first. Used for gradual migration from copy_tuner to local YAML.



139
140
141
# File 'lib/copy_tuner_client/configuration.rb', line 139

def local_first_key_regexp
  @local_first_key_regexp
end

#localesArray<Symbol>

Returns Restrict blurb locales to upload.

Returns:

  • (Array<Symbol>)

    Restrict blurb locales to upload



148
149
150
# File 'lib/copy_tuner_client/configuration.rb', line 148

def locales
  @locales
end

#loggerLogger

Returns Where to log messages. Must respond to same interface as Logger.

Returns:

  • (Logger)

    Where to log messages. Must respond to same interface as Logger.



106
107
108
# File 'lib/copy_tuner_client/configuration.rb', line 106

def logger
  @logger
end

#middlewareObject

Returns the middleware stack, if any, which should respond to use.

Returns:

  • the middleware stack, if any, which should respond to use



109
110
111
# File 'lib/copy_tuner_client/configuration.rb', line 109

def middleware
  @middleware
end

#middleware_positionObject

OtherMiddleware or OtherMiddleware



115
116
117
# File 'lib/copy_tuner_client/configuration.rb', line 115

def middleware_position
  @middleware_position
end

#pollerObject

Returns the value of attribute poller.



129
130
131
# File 'lib/copy_tuner_client/configuration.rb', line 129

def poller
  @poller
end

#polling_delayInteger

Returns The time, in seconds, in between each sync to the server. Defaults to 300.

Returns:

  • (Integer)

    The time, in seconds, in between each sync to the server. Defaults to 300.



94
95
96
# File 'lib/copy_tuner_client/configuration.rb', line 94

def polling_delay
  @polling_delay
end

#portFixnum

Returns The port on which your CopyTuner server runs (defaults to 443 for secure connections, 80 for insecure connections).

Returns:

  • (Fixnum)

    The port on which your CopyTuner server runs (defaults to 443 for secure connections, 80 for insecure connections).



46
47
48
# File 'lib/copy_tuner_client/configuration.rb', line 46

def port
  @port
end

#project_idInteger

Returns The project id.

Returns:

  • (Integer)

    The project id



160
161
162
# File 'lib/copy_tuner_client/configuration.rb', line 160

def project_id
  @project_id
end

#proxy_hostString, NilClass

Returns The hostname of your proxy server (if using a proxy).

Returns:

  • (String, NilClass)

    The hostname of your proxy server (if using a proxy)



58
59
60
# File 'lib/copy_tuner_client/configuration.rb', line 58

def proxy_host
  @proxy_host
end

#proxy_passString, NilClass

Returns The password to use when logging into your proxy server (if using a proxy).

Returns:

  • (String, NilClass)

    The password to use when logging into your proxy server (if using a proxy)



67
68
69
# File 'lib/copy_tuner_client/configuration.rb', line 67

def proxy_pass
  @proxy_pass
end

#proxy_portString, Fixnum

Returns The port of your proxy server (if using a proxy).

Returns:

  • (String, Fixnum)

    The port of your proxy server (if using a proxy)



61
62
63
# File 'lib/copy_tuner_client/configuration.rb', line 61

def proxy_port
  @proxy_port
end

#proxy_userString, NilClass

Returns The username to use when logging into your proxy server (if using a proxy).

Returns:

  • (String, NilClass)

    The username to use when logging into your proxy server (if using a proxy)



64
65
66
# File 'lib/copy_tuner_client/configuration.rb', line 64

def proxy_user
  @proxy_user
end

#s3_hostString

Returns The S3 host to connect to (defaults to copy-tuner-us.s3.amazonaws.com).

Returns:

  • (String)

    The S3 host to connect to (defaults to copy-tuner-us.s3.amazonaws.com).



142
143
144
# File 'lib/copy_tuner_client/configuration.rb', line 142

def s3_host
  @s3_host
end

#secureBoolean Also known as: secure?

Returns true for https connections, false for http connections.

Returns:

  • (Boolean)

    true for https connections, false for http connections.



49
50
51
# File 'lib/copy_tuner_client/configuration.rb', line 49

def secure
  @secure
end

#sync_ignore_path_regexRegex

Returns Format ignore hook middleware sync.

Returns:

  • (Regex)

    Format ignore hook middleware sync



103
104
105
# File 'lib/copy_tuner_client/configuration.rb', line 103

def sync_ignore_path_regex
  @sync_ignore_path_regex
end

#sync_intervalObject

Sync interval for Rack Middleware



97
98
99
# File 'lib/copy_tuner_client/configuration.rb', line 97

def sync_interval
  @sync_interval
end

#sync_interval_stagingInteger

Returns The time, in seconds, in between each sync to the server in development. Defaults to 60.

Returns:

  • (Integer)

    The time, in seconds, in between each sync to the server in development. Defaults to 60.



100
101
102
# File 'lib/copy_tuner_client/configuration.rb', line 100

def sync_interval_staging
  @sync_interval_staging
end

#test_environmentsArray<String>

Returns A list of environments in which the server should not be contacted.

Returns:

  • (Array<String>)

    A list of environments in which the server should not be contacted



73
74
75
# File 'lib/copy_tuner_client/configuration.rb', line 73

def test_environments
  @test_environments
end

#upload_disabled_environmentsArray<String>

Returns A list of environments in which the server should not be upload.

Returns:

  • (Array<String>)

    A list of environments in which the server should not be upload



76
77
78
# File 'lib/copy_tuner_client/configuration.rb', line 76

def upload_disabled_environments
  @upload_disabled_environments
end

Class Method Details

.builtin_local_first_key?(key_without_locale) ⇒ Boolean

lookup 経路(Configuration#local_first_key?)と upload 抑止経路(Cache#[]=)で同じ組み込み判定を共有する。判定を 1 箇所に集約することで number 以外を足す際の同期漏れを防ぐ。

Returns:

  • (Boolean)


35
36
37
# File 'lib/copy_tuner_client/configuration.rb', line 35

def self.builtin_local_first_key?(key_without_locale)
  key_without_locale.to_s.match?(BUILTIN_LOCAL_FIRST_KEY_REGEXP)
end

Instance Method Details

#[](option) ⇒ Object

Allows config options to be read like a hash

Parameters:

  • option (Symbol)

    Key for a given attribute

Returns:

  • (Object)

    the given attribute



199
200
201
# File 'lib/copy_tuner_client/configuration.rb', line 199

def [](option)
  send(option)
end

#applied?Boolean

Determines if the configuration has been applied (internal)

Returns:

  • (Boolean)

    Returns true if applied, false otherwise.



250
251
252
# File 'lib/copy_tuner_client/configuration.rb', line 250

def applied?
  @applied
end

#applyObject

Applies the configuration (internal).

Called automatically when CopyTunerClient.configure is called in the application.

This creates the I18nBackend and puts them together.

When #test? returns false, the poller will be started.



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/copy_tuner_client/configuration.rb', line 261

def apply
  self.locales ||= self.locales = if defined?(::Rails)
                                    ::Rails.application.config.i18n.available_locales.presence || Array(::Rails.application.config.i18n.default_locale)
                                  else
                                    [:en]
                                  end

  self.client ||= Client.new(to_hash)
  self.cache ||= Cache.new(client, to_hash)
  @poller = Poller.new(cache, to_hash)
  process_guard = ProcessGuard.new(cache, @poller, to_hash)
  I18n.backend = I18nBackend.new(cache)

  if enable_middleware?
    logger.info 'Using copytuner sync middleware'
    request_sync_options = { poller: @poller, cache:, interval: sync_interval, ignore_regex: sync_ignore_path_regex }
    if middleware_position.is_a?(Hash) && middleware_position[:before]
      middleware.insert_before middleware_position[:before], RequestSync, request_sync_options
      middleware.insert_before middleware_position[:before], CopyTunerClient::CopyrayMiddleware
    elsif middleware_position.is_a?(Hash) && middleware_position[:after]
      middleware.insert_after middleware_position[:after], RequestSync, request_sync_options
      middleware.insert_after middleware_position[:after], CopyTunerClient::CopyrayMiddleware
    else
      middleware.use RequestSync, request_sync_options
      middleware.use CopyTunerClient::CopyrayMiddleware
    end
  else
    logger.info '[[[Warn]]] Not using copytuner sync middleware' unless middleware
  end

  @applied = true
  logger.info "Client #{VERSION} ready (s3_download)"
  logger.info "Environment Info: #{environment_info}"
  logger.info "Available locales: #{self.locales.join(' ')}"

  unless test?
    process_guard.start
  end

  unless test? && disable_test_translation
    logger.info 'Download translation now'
    cache.download
  end
end

#development?Boolean

Determines if the content will be editable

Returns:

  • (Boolean)

    Returns true if in a development environment, false otherwise.



230
231
232
# File 'lib/copy_tuner_client/configuration.rb', line 230

def development?
  development_environments.include? environment_name
end

#enable_middleware?Boolean

Returns:

  • (Boolean)


234
235
236
# File 'lib/copy_tuner_client/configuration.rb', line 234

def enable_middleware?
  middleware && development? && !disable_middleware
end

#environment_infoString

For logging/debugging (internal).

Returns:

  • (String)

    a description of the environment in which this configuration was built.



322
323
324
325
# File 'lib/copy_tuner_client/configuration.rb', line 322

def environment_info
  parts = ["Ruby: #{RUBY_VERSION}", framework, "Env: #{environment_name}"]
  parts.compact.map { |part| "[#{part}]" }.join(' ')
end

#local_first_key?(key_without_locale) ⇒ Boolean

locale を除いたキーが local_first_key_regexp にマッチするかを返す。マッチするキーはローカル config/locales(CopyTuner 管理外)で管理されるため、オーバーレイマーカー注入やキャッシュ参照をスキップする必要がある。

Parameters:

  • key_without_locale (String, Symbol, nil)

    locale prefix を除いたキー(例: “views.foo.bar”)

Returns:

  • (Boolean)


380
381
382
383
384
385
386
387
388
# File 'lib/copy_tuner_client/configuration.rb', line 380

def local_first_key?(key_without_locale)
  return false if key_without_locale.nil?

  normalized = key_without_locale.to_s
  return true if self.class.builtin_local_first_key?(normalized)
  return false if local_first_key_regexp.nil?

  normalized.match?(local_first_key_regexp)
end

#merge(hash) ⇒ Hash

Returns a hash of all configurable options merged with hash

Parameters:

  • hash (Hash)

    A set of configuration options that will take precedence over the defaults

Returns:

  • (Hash)

    the merged configuration hash



217
218
219
# File 'lib/copy_tuner_client/configuration.rb', line 217

def merge(hash)
  to_hash.merge hash
end

#project_urlString

Returns current project url by api_key.

Returns:

  • (String)

    current project url by api_key



362
363
364
365
366
367
368
369
370
371
372
# File 'lib/copy_tuner_client/configuration.rb', line 362

def project_url
  path =
    if project_id
      "/projects/#{project_id}"
    else
      ActiveSupport::Deprecation.new.warn('Please set project_id.')
      "/projects/#{api_key}"
    end

  URI::Generic.build(scheme: self.protocol, host: self.host, port: self.port.to_i, path:).to_s
end

#protocolString

The protocol that should be used when generating URLs to CopyTuner.

Returns:

  • (String)

    https if #secure? returns true, http otherwise.



312
313
314
315
316
317
318
# File 'lib/copy_tuner_client/configuration.rb', line 312

def protocol
  if secure?
    'https'
  else
    'http'
  end
end

#public?Boolean

Determines if the published or draft content will be used environment, true otherwise.

Returns:

  • (Boolean)

    Returns false if in a development or test



224
225
226
# File 'lib/copy_tuner_client/configuration.rb', line 224

def public?
  !(development_environments + test_environments).include?(environment_name)
end

#test?Boolean

Determines if the content will fetched from the server

Returns:

  • (Boolean)

    Returns true if in a test environment, false otherwise.



240
241
242
# File 'lib/copy_tuner_client/configuration.rb', line 240

def test?
  test_environments.include?(environment_name)
end

#to_hashHash

Returns a hash of all configurable options

Returns:

  • (Hash)

    configuration attributes



205
206
207
208
209
210
211
# File 'lib/copy_tuner_client/configuration.rb', line 205

def to_hash
  base_options = { public: public?, upload_disabled: upload_disabled? }

  OPTIONS.inject(base_options) do |hash, option|
    hash.merge option.to_sym => send(option)
  end
end

#upload_disabled?Boolean

Returns:

  • (Boolean)


244
245
246
# File 'lib/copy_tuner_client/configuration.rb', line 244

def upload_disabled?
  upload_disabled_environments.include?(environment_name)
end