Class: CopyTunerClient::Configuration
- Inherits:
-
Object
- Object
- CopyTunerClient::Configuration
- Defined in:
- lib/copy_tuner_client/configuration.rb
Overview
Used to set up and modify settings for the client.
Constant Summary collapse
- OPTIONS =
These options will be present in the Hash returned by #to_hash.
%i[api_key development_environments environment_name host http_open_timeout http_read_timeout client_name client_url client_version port protocol proxy_host proxy_pass proxy_port proxy_user secure polling_delay sync_interval sync_interval_staging sync_ignore_path_regex logger framework middleware disable_middleware disable_test_translation ca_file exclude_key_regexp local_first_key_regexp s3_host locales ignored_keys ignored_key_handler download_cache_dir].freeze
Instance Attribute Summary collapse
-
#api_key ⇒ String
The API key for your project, found on the project edit form.
-
#ca_file ⇒ String
The path to a root certificate file used to verify ssl sessions.
-
#cache ⇒ Cache
Instance used internally to synchronize changes.
-
#client ⇒ Client
Instance used to communicate with a CopyTuner Server.
-
#client_name ⇒ String
The name of the client library being used to send notifications (defaults to CopyTuner Client).
-
#client_url ⇒ String
The url of the client library being used.
-
#client_version ⇒ String
The version of the client library being used to send notifications (such as
1.0.2). -
#development_environments ⇒ Array<String>
A list of environments in which content should be editable.
-
#disable_copyray_comment_injection ⇒ Boolean
To disable Copyray comment injection, set true.
-
#disable_middleware ⇒ Boolean
Disable middleware setting.
-
#disable_test_translation ⇒ Boolean
Disable download translation for test enviroment.
-
#download_cache_dir ⇒ Pathname
The directory to cache downloaded files.
-
#environment_name ⇒ String
The name of the environment the application is running in.
-
#exclude_key_regexp ⇒ Regexp
deprecated
Deprecated.
Use #local_first_key_regexp instead.
-
#framework ⇒ String, NilClass
The framework notifications are being sent from, if any (such as Rails 2.3.9).
-
#host ⇒ String
The host to connect to (defaults to
copy-tuner.com). -
#html_escape ⇒ Boolean
Html escape.
-
#http_open_timeout ⇒ Fixnum
The HTTP open timeout in seconds (defaults to
2). -
#http_read_timeout ⇒ Fixnum
The HTTP read timeout in seconds (defaults to
5). - #ignored_key_handler ⇒ Proc
-
#ignored_keys ⇒ Array<String>
A list of ignored keys.
-
#local_first_key_regexp ⇒ Regexp
Keys (without locale) matching this regexp bypass the copy_tuner cache and are looked up from local config/locales (I18n::Backend::Simple) first.
-
#locales ⇒ Array<Symbol>
Restrict blurb locales to upload.
-
#logger ⇒ Logger
Where to log messages.
-
#middleware ⇒ Object
The middleware stack, if any, which should respond to
use. -
#middleware_position ⇒ Object
OtherMiddleware or OtherMiddleware.
-
#poller ⇒ Object
Returns the value of attribute poller.
-
#polling_delay ⇒ Integer
The time, in seconds, in between each sync to the server.
-
#port ⇒ Fixnum
The port on which your CopyTuner server runs (defaults to
443for secure connections,80for insecure connections). -
#project_id ⇒ Integer
The project id.
-
#proxy_host ⇒ String, NilClass
The hostname of your proxy server (if using a proxy).
-
#proxy_pass ⇒ String, NilClass
The password to use when logging into your proxy server (if using a proxy).
-
#proxy_port ⇒ String, Fixnum
The port of your proxy server (if using a proxy).
-
#proxy_user ⇒ String, NilClass
The username to use when logging into your proxy server (if using a proxy).
-
#s3_host ⇒ String
The S3 host to connect to (defaults to
copy-tuner-us.s3.amazonaws.com). -
#secure ⇒ Boolean
(also: #secure?)
truefor https connections,falsefor http connections. -
#sync_ignore_path_regex ⇒ Regex
Format ignore hook middleware sync.
-
#sync_interval ⇒ Object
Sync interval for Rack Middleware.
-
#sync_interval_staging ⇒ Integer
The time, in seconds, in between each sync to the server in development.
-
#test_environments ⇒ Array<String>
A list of environments in which the server should not be contacted.
-
#upload_disabled_environments ⇒ Array<String>
A list of environments in which the server should not be upload.
Instance Method Summary collapse
-
#[](option) ⇒ Object
Allows config options to be read like a hash.
-
#applied? ⇒ Boolean
Determines if the configuration has been applied (internal).
-
#apply ⇒ Object
Applies the configuration (internal).
-
#development? ⇒ Boolean
Determines if the content will be editable.
- #enable_middleware? ⇒ Boolean
-
#environment_info ⇒ String
For logging/debugging (internal).
-
#initialize ⇒ Configuration
constructor
Instantiated from configure.
-
#local_first_key?(key_without_locale) ⇒ Boolean
locale を除いたキーが local_first_key_regexp にマッチするかを返す。 マッチするキーはローカル config/locales(CopyTuner 管理外)で管理されるため、 オーバーレイマーカー注入やキャッシュ参照をスキップする必要がある。.
-
#merge(hash) ⇒ Hash
Returns a hash of all configurable options merged with
hash. -
#project_url ⇒ String
Current project url by api_key.
-
#protocol ⇒ String
The protocol that should be used when generating URLs to CopyTuner.
-
#public? ⇒ Boolean
Determines if the published or draft content will be used environment,
trueotherwise. -
#test? ⇒ Boolean
Determines if the content will fetched from the server.
-
#to_hash ⇒ Hash
Returns a hash of all configurable options.
- #upload_disabled? ⇒ Boolean
Constructor Details
#initialize ⇒ Configuration
Instantiated from CopyTunerClient.configure. Sets defaults.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/copy_tuner_client/configuration.rb', line 153 def initialize self.client_name = 'CopyTuner Client' self.client_url = 'https://rubygems.org/gems/copy_tuner_client' self.client_version = VERSION self.development_environments = %w[development staging] self.host = 'copy-tuner.com' self.http_open_timeout = 5 self.http_read_timeout = 5 self.logger = Logger.new($stdout) self.polling_delay = 300 self.sync_interval = 60 self.sync_interval_staging = 0 self.secure = true self.test_environments = %w[test cucumber] self.upload_disabled_environments = %w[production staging] self.s3_host = 'copy-tuner.sg-apps.com' # NOTE: cloudfront host self.disable_copyray_comment_injection = false self.html_escape = true self.ignored_keys = [] self.ignored_key_handler = ->(e) { raise e } self.local_first_key_regexp = nil self.project_id = nil self.download_cache_dir = Pathname.new(Dir.pwd).join('tmp', 'cache', 'copy_tuner_client') @applied = false end |
Instance Attribute Details
#api_key ⇒ String
Returns The API key for your project, found on the project edit form.
25 26 27 |
# File 'lib/copy_tuner_client/configuration.rb', line 25 def api_key @api_key end |
#ca_file ⇒ String
Returns the path to a root certificate file used to verify ssl sessions. Default’s to the root certificate file for copy-tuner.com.
106 107 108 |
# File 'lib/copy_tuner_client/configuration.rb', line 106 def ca_file @ca_file end |
#cache ⇒ Cache
Returns instance used internally to synchronize changes.
109 110 111 |
# File 'lib/copy_tuner_client/configuration.rb', line 109 def cache @cache end |
#client ⇒ Client
Returns instance used to communicate with a CopyTuner Server.
112 113 114 |
# File 'lib/copy_tuner_client/configuration.rb', line 112 def client @client end |
#client_name ⇒ String
Returns The name of the client library being used to send notifications (defaults to CopyTuner Client).
67 68 69 |
# File 'lib/copy_tuner_client/configuration.rb', line 67 def client_name @client_name end |
#client_url ⇒ String
Returns The url of the client library being used.
76 77 78 |
# File 'lib/copy_tuner_client/configuration.rb', line 76 def client_url @client_url end |
#client_version ⇒ String
Returns The version of the client library being used to send notifications (such as 1.0.2).
73 74 75 |
# File 'lib/copy_tuner_client/configuration.rb', line 73 def client_version @client_version end |
#development_environments ⇒ Array<String>
Returns A list of environments in which content should be editable.
55 56 57 |
# File 'lib/copy_tuner_client/configuration.rb', line 55 def development_environments @development_environments end |
#disable_copyray_comment_injection ⇒ Boolean
Returns To disable Copyray comment injection, set true.
130 131 132 |
# File 'lib/copy_tuner_client/configuration.rb', line 130 def disable_copyray_comment_injection @disable_copyray_comment_injection end |
#disable_middleware ⇒ Boolean
Returns disable middleware setting.
97 98 99 |
# File 'lib/copy_tuner_client/configuration.rb', line 97 def disable_middleware @disable_middleware end |
#disable_test_translation ⇒ Boolean
Returns disable download translation for test enviroment.
103 104 105 |
# File 'lib/copy_tuner_client/configuration.rb', line 103 def disable_test_translation @disable_test_translation end |
#download_cache_dir ⇒ Pathname
Returns The directory to cache downloaded files.
148 149 150 |
# File 'lib/copy_tuner_client/configuration.rb', line 148 def download_cache_dir @download_cache_dir end |
#environment_name ⇒ String
Returns The name of the environment the application is running in.
64 65 66 |
# File 'lib/copy_tuner_client/configuration.rb', line 64 def environment_name @environment_name end |
#exclude_key_regexp ⇒ Regexp
Use #local_first_key_regexp instead.
Returns Regular expression to exclude keys.
118 119 120 |
# File 'lib/copy_tuner_client/configuration.rb', line 118 def exclude_key_regexp @exclude_key_regexp end |
#framework ⇒ String, NilClass
Returns The framework notifications are being sent from, if any (such as Rails 2.3.9).
70 71 72 |
# File 'lib/copy_tuner_client/configuration.rb', line 70 def framework @framework end |
#host ⇒ String
Returns The host to connect to (defaults to copy-tuner.com).
28 29 30 |
# File 'lib/copy_tuner_client/configuration.rb', line 28 def host @host end |
#html_escape ⇒ Boolean
Returns Html escape.
136 137 138 |
# File 'lib/copy_tuner_client/configuration.rb', line 136 def html_escape @html_escape end |
#http_open_timeout ⇒ Fixnum
Returns The HTTP open timeout in seconds (defaults to 2).
37 38 39 |
# File 'lib/copy_tuner_client/configuration.rb', line 37 def http_open_timeout @http_open_timeout end |
#http_read_timeout ⇒ Fixnum
Returns The HTTP read timeout in seconds (defaults to 5).
40 41 42 |
# File 'lib/copy_tuner_client/configuration.rb', line 40 def http_read_timeout @http_read_timeout end |
#ignored_key_handler ⇒ Proc
142 143 144 |
# File 'lib/copy_tuner_client/configuration.rb', line 142 def ignored_key_handler @ignored_key_handler end |
#ignored_keys ⇒ Array<String>
Returns A list of ignored keys.
139 140 141 |
# File 'lib/copy_tuner_client/configuration.rb', line 139 def ignored_keys @ignored_keys end |
#local_first_key_regexp ⇒ Regexp
Returns Keys (without locale) matching this regexp bypass the copy_tuner cache and are looked up from local config/locales (I18n::Backend::Simple) first. Used for gradual migration from copy_tuner to local YAML.
124 125 126 |
# File 'lib/copy_tuner_client/configuration.rb', line 124 def local_first_key_regexp @local_first_key_regexp end |
#locales ⇒ Array<Symbol>
Returns Restrict blurb locales to upload.
133 134 135 |
# File 'lib/copy_tuner_client/configuration.rb', line 133 def locales @locales end |
#logger ⇒ Logger
Returns Where to log messages. Must respond to same interface as Logger.
91 92 93 |
# File 'lib/copy_tuner_client/configuration.rb', line 91 def logger @logger end |
#middleware ⇒ Object
Returns the middleware stack, if any, which should respond to use.
94 95 96 |
# File 'lib/copy_tuner_client/configuration.rb', line 94 def middleware @middleware end |
#middleware_position ⇒ Object
OtherMiddleware or OtherMiddleware
100 101 102 |
# File 'lib/copy_tuner_client/configuration.rb', line 100 def middleware_position @middleware_position end |
#poller ⇒ Object
Returns the value of attribute poller.
114 115 116 |
# File 'lib/copy_tuner_client/configuration.rb', line 114 def poller @poller end |
#polling_delay ⇒ Integer
Returns The time, in seconds, in between each sync to the server. Defaults to 300.
79 80 81 |
# File 'lib/copy_tuner_client/configuration.rb', line 79 def polling_delay @polling_delay end |
#port ⇒ Fixnum
Returns The port on which your CopyTuner server runs (defaults to 443 for secure connections, 80 for insecure connections).
31 32 33 |
# File 'lib/copy_tuner_client/configuration.rb', line 31 def port @port end |
#project_id ⇒ Integer
Returns The project id.
145 146 147 |
# File 'lib/copy_tuner_client/configuration.rb', line 145 def project_id @project_id end |
#proxy_host ⇒ String, NilClass
Returns The hostname of your proxy server (if using a proxy).
43 44 45 |
# File 'lib/copy_tuner_client/configuration.rb', line 43 def proxy_host @proxy_host end |
#proxy_pass ⇒ String, NilClass
Returns The password to use when logging into your proxy server (if using a proxy).
52 53 54 |
# File 'lib/copy_tuner_client/configuration.rb', line 52 def proxy_pass @proxy_pass end |
#proxy_port ⇒ String, Fixnum
Returns The port of your proxy server (if using a proxy).
46 47 48 |
# File 'lib/copy_tuner_client/configuration.rb', line 46 def proxy_port @proxy_port end |
#proxy_user ⇒ String, NilClass
Returns The username to use when logging into your proxy server (if using a proxy).
49 50 51 |
# File 'lib/copy_tuner_client/configuration.rb', line 49 def proxy_user @proxy_user end |
#s3_host ⇒ String
Returns The S3 host to connect to (defaults to copy-tuner-us.s3.amazonaws.com).
127 128 129 |
# File 'lib/copy_tuner_client/configuration.rb', line 127 def s3_host @s3_host end |
#secure ⇒ Boolean Also known as: secure?
Returns true for https connections, false for http connections.
34 35 36 |
# File 'lib/copy_tuner_client/configuration.rb', line 34 def secure @secure end |
#sync_ignore_path_regex ⇒ Regex
Returns Format ignore hook middleware sync.
88 89 90 |
# File 'lib/copy_tuner_client/configuration.rb', line 88 def sync_ignore_path_regex @sync_ignore_path_regex end |
#sync_interval ⇒ Object
Sync interval for Rack Middleware
82 83 84 |
# File 'lib/copy_tuner_client/configuration.rb', line 82 def sync_interval @sync_interval end |
#sync_interval_staging ⇒ Integer
Returns The time, in seconds, in between each sync to the server in development. Defaults to 60.
85 86 87 |
# File 'lib/copy_tuner_client/configuration.rb', line 85 def sync_interval_staging @sync_interval_staging end |
#test_environments ⇒ Array<String>
Returns A list of environments in which the server should not be contacted.
58 59 60 |
# File 'lib/copy_tuner_client/configuration.rb', line 58 def test_environments @test_environments end |
#upload_disabled_environments ⇒ Array<String>
Returns A list of environments in which the server should not be upload.
61 62 63 |
# File 'lib/copy_tuner_client/configuration.rb', line 61 def upload_disabled_environments @upload_disabled_environments end |
Instance Method Details
#[](option) ⇒ Object
Allows config options to be read like a hash
184 185 186 |
# File 'lib/copy_tuner_client/configuration.rb', line 184 def [](option) send(option) end |
#applied? ⇒ Boolean
Determines if the configuration has been applied (internal)
235 236 237 |
# File 'lib/copy_tuner_client/configuration.rb', line 235 def applied? @applied end |
#apply ⇒ Object
Applies the configuration (internal).
Called automatically when CopyTunerClient.configure is called in the application.
This creates the I18nBackend and puts them together.
When #test? returns false, the poller will be started.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/copy_tuner_client/configuration.rb', line 246 def apply self.locales ||= self.locales = if defined?(::Rails) ::Rails.application.config.i18n.available_locales.presence || Array(::Rails.application.config.i18n.default_locale) else [:en] end self.client ||= Client.new(to_hash) self.cache ||= Cache.new(client, to_hash) @poller = Poller.new(cache, to_hash) process_guard = ProcessGuard.new(cache, @poller, to_hash) I18n.backend = I18nBackend.new(cache) if enable_middleware? logger.info 'Using copytuner sync middleware' = { poller: @poller, cache:, interval: sync_interval, ignore_regex: sync_ignore_path_regex } if middleware_position.is_a?(Hash) && middleware_position[:before] middleware.insert_before middleware_position[:before], RequestSync, middleware.insert_before middleware_position[:before], CopyTunerClient::CopyrayMiddleware elsif middleware_position.is_a?(Hash) && middleware_position[:after] middleware.insert_after middleware_position[:after], RequestSync, middleware.insert_after middleware_position[:after], CopyTunerClient::CopyrayMiddleware else middleware.use RequestSync, middleware.use CopyTunerClient::CopyrayMiddleware end else logger.info '[[[Warn]]] Not using copytuner sync middleware' unless middleware end @applied = true logger.info "Client #{VERSION} ready (s3_download)" logger.info "Environment Info: #{environment_info}" logger.info "Available locales: #{self.locales.join(' ')}" unless test? process_guard.start end unless test? && disable_test_translation logger.info 'Download translation now' cache.download end end |
#development? ⇒ Boolean
Determines if the content will be editable
215 216 217 |
# File 'lib/copy_tuner_client/configuration.rb', line 215 def development? development_environments.include? environment_name end |
#enable_middleware? ⇒ Boolean
219 220 221 |
# File 'lib/copy_tuner_client/configuration.rb', line 219 def enable_middleware? middleware && development? && !disable_middleware end |
#environment_info ⇒ String
For logging/debugging (internal).
307 308 309 310 |
# File 'lib/copy_tuner_client/configuration.rb', line 307 def environment_info parts = ["Ruby: #{RUBY_VERSION}", framework, "Env: #{environment_name}"] parts.compact.map { |part| "[#{part}]" }.join(' ') end |
#local_first_key?(key_without_locale) ⇒ Boolean
locale を除いたキーが local_first_key_regexp にマッチするかを返す。マッチするキーはローカル config/locales(CopyTuner 管理外)で管理されるため、オーバーレイマーカー注入やキャッシュ参照をスキップする必要がある。
365 366 367 368 369 |
# File 'lib/copy_tuner_client/configuration.rb', line 365 def local_first_key?(key_without_locale) return false if local_first_key_regexp.nil? || key_without_locale.nil? key_without_locale.to_s.match?(local_first_key_regexp) end |
#merge(hash) ⇒ Hash
Returns a hash of all configurable options merged with hash
202 203 204 |
# File 'lib/copy_tuner_client/configuration.rb', line 202 def merge(hash) to_hash.merge hash end |
#project_url ⇒ String
Returns current project url by api_key.
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/copy_tuner_client/configuration.rb', line 347 def project_url path = if project_id "/projects/#{project_id}" else ActiveSupport::Deprecation.new.warn('Please set project_id.') "/projects/#{api_key}" end URI::Generic.build(scheme: self.protocol, host: self.host, port: self.port.to_i, path:).to_s end |
#protocol ⇒ String
The protocol that should be used when generating URLs to CopyTuner.
297 298 299 300 301 302 303 |
# File 'lib/copy_tuner_client/configuration.rb', line 297 def protocol if secure? 'https' else 'http' end end |
#public? ⇒ Boolean
Determines if the published or draft content will be used environment, true otherwise.
209 210 211 |
# File 'lib/copy_tuner_client/configuration.rb', line 209 def public? !(development_environments + test_environments).include?(environment_name) end |
#test? ⇒ Boolean
Determines if the content will fetched from the server
225 226 227 |
# File 'lib/copy_tuner_client/configuration.rb', line 225 def test? test_environments.include?(environment_name) end |
#to_hash ⇒ Hash
Returns a hash of all configurable options
190 191 192 193 194 195 196 |
# File 'lib/copy_tuner_client/configuration.rb', line 190 def to_hash = { public: public?, upload_disabled: upload_disabled? } OPTIONS.inject() do |hash, option| hash.merge option.to_sym => send(option) end end |
#upload_disabled? ⇒ Boolean
229 230 231 |
# File 'lib/copy_tuner_client/configuration.rb', line 229 def upload_disabled? upload_disabled_environments.include?(environment_name) end |